unit CErrores;

interface

procedure StartLog(const AFileName: string);
procedure StopLog;

implementation

uses  SysUtils, forms, dialogs, Windows;

type
  TExceptionLog = class
  protected
    SavedHandler: TExceptionEvent;
    FileName: string;
    procedure ExceptionHandler(Sender: TObject; E: Exception);
  public
    constructor Create(const AFileName: string);
    destructor Destroy; override;
  end;

{ TExceptionLog }

constructor TExceptionLog.Create(const AFileName: string);
begin
  inherited Create;
  FileName := AFileName;
  SavedHandler := Application.OnException;
  Application.OnException := ExceptionHandler;
end;

destructor TExceptionLog.Destroy;
begin
  Application.OnException := SavedHandler;
  inherited Destroy;
end;

procedure TExceptionLog.ExceptionHandler(Sender: TObject; E: Exception);
var
  Txt: TextFile;
begin
  MessageBox (0, pchar('Se ha producido el siguiente error:' +
     chr(13) + chr(13) + E.Message),
      pchar('Error...'), (MB_OK + MB_ICONSTOP));
  try
    AssignFile(Txt, FileName);
    try
      Append(Txt);
    except
      Rewrite(Txt);
    end;
    try
      WriteLn(Txt, 'Error: ' + DateTimeToStr(Now), ' -> ',
        E.ClassName, ': ', E.Message);
    finally
      CloseFile(Txt);
    end;
  except
  end;
  screen.cursor:=0;
end;

{ Interface procedures }

var
  Log: TExceptionLog = nil;

procedure StartLog(const AFileName: string);
begin
  if not Assigned(Log) then
    Log := TExceptionLog.Create(AFileName);
end;

procedure StopLog;
begin
  if Assigned(Log) then
  begin
    Log.Free;
    Log := nil;
  end;
end;

initialization
finalization
  StopLog;
end.
