unit UnidadVisorArchivos;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, StdCtrls, FileCtrl, Jpeg;

type
  TFormVisorArchivos = class(TForm)
    CUnidades: TDriveComboBox;
    CDirectorios: TDirectoryListBox;
    CArchivos: TFileListBox;
    CFiltros: TFilterComboBox;
    CTexto: TMemo;
    CImagen: TImage;
    Bevel1: TBevel;
    BEliminar: TButton;
    BRenombrar: TButton;
    BCerrar: TButton;
    Bevel2: TBevel;
    procedure CArchivosChange(Sender: TObject);
    procedure BCerrarClick(Sender: TObject);
    procedure BEliminarClick(Sender: TObject);
    procedure BRenombrarClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  FormVisorArchivos: TFormVisorArchivos;

implementation

{$R *.DFM}

    // Cada vez que cambie el archivo seleccionado
    // en la lista
procedure TFormVisorArchivos.CArchivosChange(Sender: TObject);
Var
   Extension: String[4]; // Para obtener la extensin del archivo
begin

     CTexto.Visible := False;  // Ocultar cualquier image o texto anterior
     CImagen.Visible := False;

     Extension := ExtractFileExt(CArchivos.FileName); // Obtenemos la extensin del archivo seleccionado

     If (UpperCase(Extension) = '.BMP') Or
        (UpperCase(Extension) = '.ICO') Or
        (UpperCase(Extension) = '.JPG') Or
        (UpperCase(Extension) = '.WMF') Then // Si se trata de un grfico
      Begin
              // Cargar la imagen
           Try // Proteger la carga de una posible excepcin
            CImagen.Picture.LoadFromFile(CArchivos.FileName);
           Except On Exception Do
                  ShowMessage('No es posible mostrar este archivo');
           End;

           CImagen.Visible := True; // y hacerla visible
      End
     Else If UpperCase(Extension) = '.TXT' Then // Si se trata de un texto
      Begin
              // Cargar el archivo de texto, capturando una posible excepcin
           Try
            CTexto.Lines.LoadFromFile(CArchivos.FileName);
           Except On Exception Do
                  ShowMessage('No es posible mostrar este archivo');
           End;

           CTexto.Visible := True; // y mostrarlo
      End;
end;

procedure TFormVisorArchivos.BCerrarClick(Sender: TObject);
begin
     Close; // Cerrar la ventana
end;

procedure TFormVisorArchivos.BEliminarClick(Sender: TObject);
begin
       // Pedir confirmacin del borrado
     If MessageDlg('Desea borrar ' + CArchivos.Filename + '?',
                   mtConfirmation, [mbYes, mbNo], 0) = mrYes Then
      If DeleteFile(PChar(CArchivos.FileName)) = False Then // Si no es posible borrar
         ShowMessage('No es posible eliminar el archivo')
      Else
        CArchivos.Update; // Actualizar la lista de archivos
end;

procedure TFormVisorArchivos.BRenombrarClick(Sender: TObject);
Var
   NuevoNombre: String;
begin
                // Solicitar el nuevo nombre para el archivo
     If InputQuery('Renombrar', 'Introduzca el nuevo nombre', NuevoNombre) = True Then
       If RenameFile(CArchivos.FileName, NuevoNombre) = False Then // Si se produce un fallo
          ShowMessage('Nombre invlido o ya existente, no se ha renombrado')
       Else
           CArchivos.Update; // Actualizar la lista de archivos
end;

procedure TFormVisorArchivos.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  action:=cafree;
end;

end.

